@@ -55,10 +55,10 @@ def issue(src_path: str,
     # calc hash
     hash_str = Utils.calc_hash(dest_path)
 
-    if check_revoked_hash(hash_str):
+    if check_revoked_hash(hash_str, certify_address, node_url):
         raise ValueError("Certificate revoked")
 
-    if check_hash_exists(hash_str):
+    if check_hash_exists(hash_str, certify_address, node_url):
         raise ValueError("Certificate already registered")
 
     cp = Utils.prepare_chainpoint_tree([hash_str])
